@@ -13,23 +13,34 @@
 import json
 import yaml
 
-from heatclient.openstack.common._i18n import _
+from heatclient._i18n import _
 
 if hasattr(yaml, 'CSafeLoader'):
-    yaml_loader = yaml.CSafeLoader
+    yaml_loader_base = yaml.CSafeLoader
 else:
-    yaml_loader = yaml.SafeLoader
+    yaml_loader_base = yaml.SafeLoader
 
 if hasattr(yaml, 'CSafeDumper'):
-    yaml_dumper = yaml.CSafeDumper
+    yaml_dumper_base = yaml.CSafeDumper
 else:
-    yaml_dumper = yaml.SafeDumper
+    yaml_dumper_base = yaml.SafeDumper
+
+
+# We create custom class to not overriden the default yaml behavior
+class yaml_loader(yaml_loader_base):
+    pass
+
+
+class yaml_dumper(yaml_dumper_base):
+    pass
 
 
 def _construct_yaml_str(self, node):
     # Override the default string handling function
     # to always return unicode objects
     return self.construct_scalar(node)
+
+
 yaml_loader.add_constructor(u'tag:yaml.org,2002:str', _construct_yaml_str)
 # Unquoted dates like 2013-05-23 in yaml files get loaded as objects of type
 # datetime.data which causes problems in API layer when being processed by
