@@ -20,14 +20,15 @@ from six.moves.urllib import error
 from six.moves.urllib import parse
 from six.moves.urllib import request
 
+from heatclient._i18n import _
 from heatclient.common import environment_format
 from heatclient.common import template_format
 from heatclient.common import utils
 from heatclient import exc
-from heatclient.openstack.common._i18n import _
 
 
-def process_template_path(template_path, object_request=None, existing=False):
+def process_template_path(template_path, object_request=None,
+                          existing=False, fetch_child=True):
     """Read template from template path.
 
     Attempt to read template first as a file or url. If that is unsuccessful,
@@ -37,17 +38,20 @@ def process_template_path(template_path, object_request=None, existing=False):
     :param object_request: custom object request function used to get template
                            if local or uri path fails
     :param existing: if the current stack's template should be used
+    :param fetch_child: Whether to fetch the child templates
     :returns: get_file dict and template contents
     :raises: error.URLError
     """
     try:
         return get_template_contents(template_file=template_path,
-                                     existing=existing)
+                                     existing=existing,
+                                     fetch_child=fetch_child)
     except error.URLError as template_file_exc:
         try:
             return get_template_contents(template_object=template_path,
                                          object_request=object_request,
-                                         existing=existing)
+                                         existing=existing,
+                                         fetch_child=fetch_child)
         except exc.HTTPNotFound:
             # The initial exception gives the user better failure context.
             raise template_file_exc
@@ -55,7 +59,8 @@ def process_template_path(template_path, object_request=None, existing=False):
 
 def get_template_contents(template_file=None, template_url=None,
                           template_object=None, object_request=None,
-                          files=None, existing=False):
+                          files=None, existing=False,
+                          fetch_child=True):
 
     is_object = False
     # Transform a bare file path to a file:// URL.
@@ -74,11 +79,13 @@ def get_template_contents(template_file=None, template_url=None,
         return {}, None
     else:
         raise exc.CommandError(_('Need to specify exactly one of '
-                               '%(arg1)s, %(arg2)s or %(arg3)s') %
+                                 '[%(arg1)s, %(arg2)s or %(arg3)s]'
+                                 ' or %(arg4)s') %
                                {
                                    'arg1': '--template-file',
                                    'arg2': '--template-url',
-                                   'arg3': '--template-object'})
+                                   'arg3': '--template-object',
+                                   'arg4': '--existing'})
 
     if not tpl:
         raise exc.CommandError(_('Could not fetch template from %s')
@@ -91,12 +98,13 @@ def get_template_contents(template_file=None, template_url=None,
     except ValueError as e:
         raise exc.CommandError(_('Error parsing template %(url)s %(error)s') %
                                {'url': template_url, 'error': e})
-
-    tmpl_base_url = utils.base_url_for_url(template_url)
     if files is None:
         files = {}
-    resolve_template_get_files(template, files, tmpl_base_url, is_object,
-                               object_request)
+
+    if fetch_child:
+        tmpl_base_url = utils.base_url_for_url(template_url)
+        resolve_template_get_files(template, files, tmpl_base_url, is_object,
+                                   object_request)
     return files, template
 
 
@@ -144,7 +152,7 @@ def get_file_contents(from_data, files, base_url=None,
                               is_object, object_request)
 
     if isinstance(from_data, dict):
-        for key, value in six.iteritems(from_data):
+        for key, value in from_data.items():
             if ignore_if and ignore_if(key, value):
                 continue
 
@@ -188,10 +196,19 @@ def normalise_file_path_to_url(path):
 
 def deep_update(old, new):
     '''Merge nested dictionaries.'''
+
+    # Prevents an error if in a previous iteration
+    # old[k] = None but v[k] = {...},
+    if old is None:
+        old = {}
+
     for k, v in new.items():
         if isinstance(v, collections.Mapping):
             r = deep_update(old.get(k, {}), v)
             old[k] = r
+        elif v is None and isinstance(old.get(k), collections.Mapping):
+            # Don't override empty data, to work around yaml syntax issue
+            pass
         else:
             old[k] = new[k]
     return old
@@ -201,7 +218,8 @@ def process_multiple_environments_and_files(env_paths=None, template=None,
                                             template_url=None,
                                             env_path_is_object=None,
                                             object_request=None,
-                                            env_list_tracker=None):
+                                            env_list_tracker=None,
+                                            fetch_env_files=True):
     """Reads one or more environment files.
 
     Reads in each specified environment file and returns a dictionary
@@ -228,6 +246,7 @@ def process_multiple_environments_and_files(env_paths=None, template=None,
     :type  env_list_tracker: list or None
     :return: tuple of files dict and a dict of the consolidated environment
     :rtype:  tuple
+    :param fetch_env_files: fetch env_files or leave it to server
     """
     merged_files = {}
     merged_env = {}
@@ -238,24 +257,28 @@ def process_multiple_environments_and_files(env_paths=None, template=None,
 
     if env_paths:
         for env_path in env_paths:
-            files, env = process_environment_and_files(
-                env_path=env_path,
-                template=template,
-                template_url=template_url,
-                env_path_is_object=env_path_is_object,
-                object_request=object_request,
-                include_env_in_files=include_env_in_files)
+            if fetch_env_files:
+                files, env = process_environment_and_files(
+                    env_path=env_path,
+                    template=template,
+                    template_url=template_url,
+                    env_path_is_object=env_path_is_object,
+                    object_request=object_request,
+                    include_env_in_files=include_env_in_files)
 
-            # 'files' looks like {"filename1": contents, "filename2": contents}
-            # so a simple update is enough for merging
-            merged_files.update(files)
+                # 'files' looks like:
+                # {"filename1": contents, "filename2": contents}
+                # so a simple update is enough for merging
+                merged_files.update(files)
 
-            # 'env' can be a deeply nested dictionary, so a simple update is
-            # not enough
-            merged_env = deep_update(merged_env, env)
+                # 'env' can be a deeply nested dictionary, so a simple
+                # update is not enough
+                merged_env = deep_update(merged_env, env)
+                env_url = utils.normalise_file_path_to_url(env_path)
+            else:
+                env_url = env_path
 
             if env_list_tracker is not None:
-                env_url = utils.normalise_file_path_to_url(env_path)
                 env_list_tracker.append(env_url)
 
     return merged_files, merged_env
@@ -345,7 +368,7 @@ def resolve_environment_urls(resource_registry, files, env_base_url,
     get_file_contents(rr, files, base_url, ignore_if,
                       is_object=is_object, object_request=object_request)
 
-    for res_name, res_dict in six.iteritems(rr.get('resources', {})):
+    for res_name, res_dict in rr.get('resources', {}).items():
         res_base_url = res_dict.get('base_url', base_url)
         get_file_contents(
             res_dict, files, res_base_url, ignore_if,
