@@ -21,7 +21,6 @@ import uuid
 
 from oslo_serialization import jsonutils
 from oslo_utils import encodeutils
-from oslo_utils import importutils
 import prettytable
 import six
 from six.moves.urllib import error
@@ -29,10 +28,8 @@ from six.moves.urllib import parse
 from six.moves.urllib import request
 import yaml
 
+from heatclient._i18n import _
 from heatclient import exc
-from heatclient.openstack.common._i18n import _
-from heatclient.openstack.common._i18n import _LE
-from heatclient.openstack.common import cliutils
 
 LOG = logging.getLogger(__name__)
 
@@ -42,10 +39,94 @@ supported_formats = {
     "yaml": yaml.safe_dump
 }
 
-# Using common methods from oslo cliutils
-arg = cliutils.arg
-env = cliutils.env
-print_list = cliutils.print_list
+
+def arg(*args, **kwargs):
+    """Decorator for CLI args.
+
+    Example:
+
+    >>> @arg("name", help="Name of the new entity")
+    ... def entity_create(args):
+    ...     pass
+    """
+    def _decorator(func):
+        add_arg(func, *args, **kwargs)
+        return func
+    return _decorator
+
+
+def env(*args, **kwargs):
+    """Returns the first environment variable set.
+
+    If all are empty, defaults to '' or keyword arg `default`.
+    """
+    for arg in args:
+        value = os.environ.get(arg)
+        if value:
+            return value
+    return kwargs.get('default', '')
+
+
+def add_arg(func, *args, **kwargs):
+    """Bind CLI arguments to a shell.py `do_foo` function."""
+
+    if not hasattr(func, 'arguments'):
+        func.arguments = []
+
+    # NOTE(sirp): avoid dups that can occur when the module is shared across
+    # tests.
+    if (args, kwargs) not in func.arguments:
+        # Because of the semantics of decorator composition if we just append
+        # to the options list positional options will appear to be backwards.
+        func.arguments.insert(0, (args, kwargs))
+
+
+def print_list(objs, fields, formatters=None, sortby_index=0,
+               mixed_case_fields=None, field_labels=None):
+    """Print a list of objects as a table, one row per object.
+
+    :param objs: iterable of :class:`Resource`
+    :param fields: attributes that correspond to columns, in order
+    :param formatters: `dict` of callables for field formatting
+    :param sortby_index: index of the field for sorting table rows
+    :param mixed_case_fields: fields corresponding to object attributes that
+        have mixed case names (e.g., 'serverId')
+    :param field_labels: Labels to use in the heading of the table, default to
+        fields.
+    """
+    formatters = formatters or {}
+    mixed_case_fields = mixed_case_fields or []
+    field_labels = field_labels or fields
+    if len(field_labels) != len(fields):
+        raise ValueError(_("Field labels list %(labels)s has different number "
+                           "of elements than fields list %(fields)s"),
+                         {'labels': field_labels, 'fields': fields})
+
+    if sortby_index is None:
+        kwargs = {}
+    else:
+        kwargs = {'sortby': field_labels[sortby_index]}
+    pt = prettytable.PrettyTable(field_labels)
+    pt.align = 'l'
+
+    for o in objs:
+        row = []
+        for field in fields:
+            if field in formatters:
+                row.append(formatters[field](o))
+            else:
+                if field in mixed_case_fields:
+                    field_name = field.replace(' ', '_')
+                else:
+                    field_name = field.lower().replace(' ', '_')
+                data = getattr(o, field_name, '')
+                row.append(data)
+        pt.add_row(row)
+
+    if six.PY3:
+        print(encodeutils.safe_encode(pt.get_string(**kwargs)).decode())
+    else:
+        print(encodeutils.safe_encode(pt.get_string(**kwargs)))
 
 
 def link_formatter(links):
@@ -89,7 +170,7 @@ def print_dict(d, formatters=None):
                                  caching=False, print_empty=False)
     pt.align = 'l'
 
-    for field in d.keys():
+    for field in d:
         if field in formatters:
             pt.add_row([field, formatters[field](d[field])])
         else:
@@ -97,16 +178,86 @@ def print_dict(d, formatters=None):
     print(pt.get_string(sortby='Property'))
 
 
-def event_log_formatter(events):
+class EventLogContext(object):
+
+    def __init__(self):
+        # key is a stack id or the name of the nested stack, value is a tuple
+        # of the parent stack id, and the name of the resource in the parent
+        # stack
+        self.id_to_res_info = {}
+
+    def prepend_paths(self, resource_path, stack_id):
+        if stack_id not in self.id_to_res_info:
+            return
+        stack_id, res_name = self.id_to_res_info.get(stack_id)
+        if res_name in self.id_to_res_info:
+            # do a double lookup to skip the ugly stack name that doesn't
+            # correspond to an actual resource name
+            n_stack_id, res_name = self.id_to_res_info.get(res_name)
+            resource_path.insert(0, res_name)
+            self.prepend_paths(resource_path, n_stack_id)
+        elif res_name:
+            resource_path.insert(0, res_name)
+
+    def build_resource_name(self, event):
+        res_name = getattr(event, 'resource_name')
+
+        # Contribute this event to self.id_to_res_info to assist with
+        # future calls to build_resource_name
+
+        def get_stack_id():
+            if getattr(event, 'stack_id', None) is not None:
+                return event.stack_id
+            for l in getattr(event, 'links', []):
+                if l.get('rel') == 'stack':
+                    if 'href' not in l:
+                        return None
+                    stack_link = l['href']
+                    return stack_link.split('/')[-1]
+
+        stack_id = get_stack_id()
+        if not stack_id:
+            return res_name
+        phys_id = getattr(event, 'physical_resource_id', None)
+        status = getattr(event, 'resource_status', None)
+
+        is_stack_event = stack_id == phys_id
+        if is_stack_event:
+            # this is an event for a stack
+            self.id_to_res_info[stack_id] = (stack_id, res_name)
+        elif phys_id and status == 'CREATE_IN_PROGRESS':
+            # this might be an event for a resource which creates a stack
+            self.id_to_res_info[phys_id] = (stack_id, res_name)
+
+        # Now build this resource path based on previous calls to
+        # build_resource_name
+        resource_path = []
+        if res_name and not is_stack_event:
+            resource_path.append(res_name)
+        self.prepend_paths(resource_path, stack_id)
+
+        return '.'.join(resource_path)
+
+
+def event_log_formatter(events, event_log_context=None):
     """Return the events in log format."""
     event_log = []
     log_format = ("%(event_time)s "
                   "[%(rsrc_name)s]: %(rsrc_status)s  %(rsrc_status_reason)s")
+
+    # It is preferable for a context to be passed in, but there might be enough
+    # events in this call to build a better resource name, so create a context
+    # anyway
+    if event_log_context is None:
+        event_log_context = EventLogContext()
+
     for event in events:
+        rsrc_name = event_log_context.build_resource_name(event)
+
         event_time = getattr(event, 'event_time', '')
         log = log_format % {
             'event_time': event_time.replace('T', ' '),
-            'rsrc_name': getattr(event, 'resource_name', ''),
+            'rsrc_name': rsrc_name,
             'rsrc_status': getattr(event, 'resource_status', ''),
             'rsrc_status_reason': getattr(event, 'resource_status_reason', '')
         }
@@ -171,13 +322,6 @@ def find_resource(manager, name_or_id):
         raise exc.CommandError(msg)
 
 
-def import_versioned_module(version, submodule=None):
-    module = 'heatclient.v%s' % version
-    if submodule:
-        module = '.'.join((module, submodule))
-    return importutils.import_module(module)
-
-
 def format_parameters(params, parse_semicolon=True):
     '''Reformat parameters into dict of format expected by the API.'''
 
@@ -232,9 +376,9 @@ def format_parameter_file(param_files, template_file=None,
             template_file, template_url))
 
     param_file = {}
-    for key, value in six.iteritems(params):
-                param_file[key] = resolve_param_get_file(value,
-                                                         template_base_url)
+    for key, value in params.items():
+        param_file[key] = resolve_param_get_file(value,
+                                                 template_base_url)
     return param_file
 
 
@@ -299,7 +443,7 @@ def get_response_body(resp):
         try:
             body = resp.json()
         except ValueError:
-            LOG.error(_LE('Could not decode response body as JSON'))
+            LOG.error('Could not decode response body as JSON')
     else:
         body = None
     return body
