@@ -19,10 +19,10 @@ from cliff.formatters import base
 from osc_lib.command import command
 from osc_lib import utils
 
+from heatclient._i18n import _
 from heatclient.common import event_utils
 from heatclient.common import utils as heat_utils
 from heatclient import exc
-from heatclient.openstack.common._i18n import _
 
 
 class ShowEvent(command.ShowOne):
@@ -137,7 +137,12 @@ class ListEvent(command.Lister):
             action='append',
             help=_('Sort output by selected keys and directions (asc or desc) '
                    '(default: asc). Specify multiple times to sort on '
-                   'multiple keys')
+                   'multiple keys. Sort key can be: '
+                   '"event_time" (default), "resource_name", "links", '
+                   '"logical_resource_id", "resource_status", '
+                   '"resource_status_reason", "physical_resource_id", or '
+                   '"id". You can leave the key empty and specify ":desc" '
+                   'for sorting by reverse time.')
         )
         parser.add_argument(
             '--follow',
@@ -170,6 +175,20 @@ class ListEvent(command.Lister):
         else:
             nested_depth = 0
 
+        if parsed_args.sort:
+            sorts = []
+            sort_keys = []
+            for sort in parsed_args.sort:
+                if sort.startswith(":"):
+                    sorts.append(":".join(["event_time", sort.lstrip(":")]))
+                else:
+                    sorts.append(sort)
+                    sort_keys.append(sort.split(":")[0])
+            kwargs['sort_keys'] = sort_keys
+
+            if ":" in parsed_args.sort[0]:
+                kwargs['sort_dir'] = parsed_args.sort[0].split(":")[1]
+
         if parsed_args.follow:
             if parsed_args.formatter != 'log':
                 msg = _('--follow can only be specified with --format log')
@@ -177,6 +196,7 @@ class ListEvent(command.Lister):
 
             marker = parsed_args.marker
             try:
+                event_log_context = heat_utils.EventLogContext()
                 while True:
                     events = event_utils.get_events(
                         client,
@@ -186,7 +206,8 @@ class ListEvent(command.Lister):
                         marker=marker)
                     if events:
                         marker = getattr(events[-1], 'id', None)
-                        events_log = heat_utils.event_log_formatter(events)
+                        events_log = heat_utils.event_log_formatter(
+                            events, event_log_context)
                         self.app.stdout.write(events_log)
                         self.app.stdout.write('\n')
                     time.sleep(5)
@@ -200,7 +221,7 @@ class ListEvent(command.Lister):
             limit=parsed_args.limit)
 
         if parsed_args.sort:
-            events = utils.sort_items(events, ','.join(parsed_args.sort))
+            events = utils.sort_items(events, ','.join(sorts))
 
         if parsed_args.formatter == 'log':
             return [], events
