@@ -15,11 +15,11 @@
 
 import logging
 
-from cliff import lister
-from openstackclient.common import utils
+from osc_lib.command import command
+from osc_lib import utils
 
 
-class ListService(lister.Lister):
+class ListService(command.Lister):
     """List the Heat engines."""
 
     log = logging.getLogger(__name__ + ".ListService")
@@ -32,8 +32,8 @@ class ListService(lister.Lister):
         self.log.debug("take_action(%s)", parsed_args)
 
         heat_client = self.app.client_manager.orchestration
-        columns = ['hostname', 'binary', 'engine_id', 'host',
-                   'topic', 'updated_at', 'status']
+        columns = ['Hostname', 'Binary', 'Engine ID', 'Host',
+                   'Topic', 'Updated At', 'Status']
         services = heat_client.services.list()
         return (
             columns,
